summaryrefslogtreecommitdiff
path: root/debugger/dbfileio.c
diff options
context:
space:
mode:
authorJung-uk Kim <jkim@FreeBSD.org>2011-11-23 18:05:37 +0000
committerJung-uk Kim <jkim@FreeBSD.org>2011-11-23 18:05:37 +0000
commit50796274dc74454ca64a6e120552adb2620c3e65 (patch)
tree91526f3e19920a98573c3d04bbef39cd71a7c0ce /debugger/dbfileio.c
parent33c583d0c71a12a703f849679505114e27bba011 (diff)
Notes
Diffstat (limited to 'debugger/dbfileio.c')
-rw-r--r--debugger/dbfileio.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/debugger/dbfileio.c b/debugger/dbfileio.c
index 8d0ef0aaa8912..7854de37bdd28 100644
--- a/debugger/dbfileio.c
+++ b/debugger/dbfileio.c
@@ -271,10 +271,11 @@ AcpiDbReadTable (
fseek (fp, 0, SEEK_SET);
/* The RSDT and FACS tables do not have standard ACPI headers */
if (ACPI_COMPARE_NAME (TableHeader.Signature, "RSD ") ||
- ACPI_COMPARE_NAME (TableHeader.Signature, "FACS"))
+ ACPI_COMPARE_NAME (TableHeader.Signature, "FACS") ||
+ ACPI_COMPARE_NAME (TableHeader.Signature, "S3PT"))
{
*TableLength = FileSize;
StandardHeader = FALSE;
@@ -271,10 +271,11 @@ AcpiDbReadTable (
fseek (fp, 0, SEEK_SET);
- /* The RSDT and FACS tables do not have standard ACPI headers */
+ /* The RSDT, FACS and S3PT tables do not have standard ACPI headers */
if (ACPI_COMPARE_NAME (TableHeader.Signature, "RSD ") ||